camelot.camelot.model.authentication.Organization.Admin

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Organization :: Class Admin |
[hide private]
[frames] | no frames]

# Class Admin

source code

Instance Methods | [hide private]
Inherited from `view.elixir_admin.EntityAdmin`: `__init__`, `__str__`, `createFormView`, `createNewView`, `createSelectView`, `createTableView`, `createValidator`, `getColumns`, `getFieldAttributes`, `getFields`, `getFilters`, `getForm`, `getFormActions`, `getListCharts`, `getModelThread`, `getName`, `getRelatedEntityAdmin`, `getSubclasses`, `setDefaults` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| name = `'Organizations'`
| section = `'relations'`
| list_display = `['name', 'tax_id',]`
| form = `TabForm([('Basic', Form(['name', 'tax_id', 'addresses',`...``
Inherited from `Party.Admin`: `field_attributes`, `fields` Inherited from `view.elixir_admin.EntityAdmin`: `form_actions`, `form_display`, `form_size`, `form_title_column`, `list_actions`, `list_charts`, `list_filter`, `list_size`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### form Value:
      TabForm([('Basic', Form(['name', 'tax_id', 'addresses', 'contact_mecha
      nisms'])), ('Employment', Form(['employees'])), ('Customers', Form(['c
      ustomers'])), ('Suppliers', Form(['suppliers'])), ('Corporate', Form([
      'directors', 'shareholders', 'shares'])), ('Branding', Form(['logo']))
      ,])